@@ -35,9 +35,9 @@ Q_DECLARE_JNI_CLASS(QtVideoDeviceManager,
 
 Q_DECLARE_JNI_CLASS(AndroidImageFormat, "android/graphics/ImageFormat");
 
-Q_DECLARE_JNI_TYPE(AndroidImage, "Landroid/media/Image;")
+Q_DECLARE_JNI_CLASS(AndroidImage, "android/media/Image")
 Q_DECLARE_JNI_TYPE(AndroidImagePlaneArray, "[Landroid/media/Image$Plane;")
-Q_DECLARE_JNI_TYPE(JavaByteBuffer, "Ljava/nio/ByteBuffer;")
+Q_DECLARE_JNI_CLASS(JavaByteBuffer, "java/nio/ByteBuffer")
 Q_DECLARE_JNI_TYPE(StringArray, "[Ljava/lang/String;")
 
 QT_BEGIN_NAMESPACE
@@ -74,7 +74,7 @@ bool checkCameraPermission()
 
 int sensorOrientation(QString cameraId)
 {
-    QJniObject deviceManager(QtJniTypes::className<QtJniTypes::QtVideoDeviceManager>(),
+    QJniObject deviceManager(QtJniTypes::Traits<QtJniTypes::QtVideoDeviceManager>::className(),
                              QNativeInterface::QAndroidApplication::context());
 
     if (!deviceManager.isValid()) {
@@ -91,7 +91,7 @@ int sensorOrientation(QString cameraId)
 
 QAndroidCamera::QAndroidCamera(QCamera *camera) : QPlatformCamera(camera)
 {
-    m_jniCamera = QJniObject(QtJniTypes::className<QtJniTypes::QtCamera2>(),
+    m_jniCamera = QJniObject(QtJniTypes::Traits<QtJniTypes::QtCamera2>::className(),
                              QNativeInterface::QAndroidApplication::context());
 
     m_hwAccel = QFFmpeg::HWAccel::create(AVHWDeviceType::AV_HWDEVICE_TYPE_MEDIACODEC);
@@ -215,7 +215,7 @@ void QAndroidCamera::frameAvailable(QJniObject image, bool takePhoto)
     lastTimestamp = timestamp;
 }
 
-QVideo::RotationAngle QAndroidCamera::rotation()
+QVideoFrame::RotationAngle QAndroidCamera::rotation()
 {
     auto screen = QGuiApplication::primaryScreen();
     auto screenOrientation = screen->orientation();
@@ -243,7 +243,7 @@ QVideo::RotationAngle QAndroidCamera::rotation()
     int sign = (m_cameraDevice.position() == QCameraDevice::Position::FrontFace) ? 1 : -1;
     int rotation = (sensorOrientation(m_cameraDevice.id()) - deviceOrientation * sign + 360) % 360;
 
-    return QVideo::RotationAngle(rotation);
+    return QVideoFrame::RotationAngle(rotation);
 }
 
 void QAndroidCamera::setActive(bool active)
@@ -347,7 +347,7 @@ void QAndroidCamera::updateCameraCharacteristics()
         return;
     }
 
-    QJniObject deviceManager(QtJniTypes::className<QtJniTypes::QtVideoDeviceManager>(),
+    QJniObject deviceManager(QtJniTypes::Traits<QtJniTypes::QtVideoDeviceManager>::className(),
                              QNativeInterface::QAndroidApplication::context());
 
     if (!deviceManager.isValid()) {
@@ -663,7 +663,7 @@ bool QAndroidCamera::registerNativeMethods()
 {
     static const bool registered = []() {
         return QJniEnvironment().registerNativeMethods(
-                QtJniTypes::className<QtJniTypes::QtCamera2>(),
+                QtJniTypes::Traits<QtJniTypes::QtCamera2>::className(),
                 {
                         Q_JNI_NATIVE_METHOD(onCameraOpened),
                         Q_JNI_NATIVE_METHOD(onCameraDisconnect),
